@@ -557,7 +557,7 @@ impl PathFilesystem for Filesystem {
         if let Some(inner_writer) = file.inner_writer {
             let mut lock = inner_writer.lock().await;
             let res = lock.writer.close().await.map_err(opendal_error2errno);
-            return res;
+            return res.map(|_| ());
         }
 
         if matches!(path, Some(ref p) if p != &file.path) {
